@@ -126,7 +126,7 @@ class Circuit:
         # Ensures the same order of switches between calls so switch configurations can be stored reliably.
         return [branch for branch in self._component_branches.reverse if isinstance(branch, SwitchBranch)]
 
-    def simulate(self, ts1: float, ts2: float, steps: int) -> TransientSimulation:
+    def simulate(self, ts1: float, ts2: float, steps: int, preferred_ground_nodes=frozenset()) -> TransientSimulation:
         """
         Perform a circuit simulation.
 
@@ -169,6 +169,8 @@ class Circuit:
             Point in time to simulate up to.
         :param steps:
             The number of steps to simulate between `t1` and `t2` (`t1` and `t2` included).
+        :param preferred_ground_nodes:
+            Notes to prefer as ground (GND).
         :return:
             A `TransientSimulation` to access the result of the simulation from.
             Note that computation happens *asynchronously*!
@@ -178,18 +180,23 @@ class Circuit:
 
         simulation = TransientSimulation(ts1, ts2, self._component_branches, self._graph.nodes)
 
-        def simulate_async(simulation, ts1, ts2, steps):
+        def simulate_async(simulation, ts1, ts2, steps, preferred_ground_nodes):
             try:
-                self._simulate(simulation, ts1, ts2, steps)
+                self._simulate(simulation, ts1, ts2, steps, preferred_ground_nodes)
             except Exception as ex:
                 simulation.abort(ex)
 
         Thread(target=simulate_async,
-               args=(simulation, ts1, ts2, steps)).start()
+               args=(simulation, ts1, ts2, steps, preferred_ground_nodes)).start()
 
         return simulation
 
-    def _simulate(self, simulation: TransientSimulation, ts1: float, ts2: float, steps: int):
+    def _simulate(self,
+                  simulation: TransientSimulation,
+                  ts1: float,
+                  ts2: float,
+                  steps: int,
+                  preferred_gnd_nodes=frozenset()):
         # A standard list is explicitly needed to allow modifications during iteration.
         ts = list(np.linspace(ts1, ts2, steps))
 
@@ -234,10 +241,11 @@ class Circuit:
                 try:
                     # Prefer ground nodes from a previous simulation.
                     _, (_, eq) = self._cache.circuit_switch_configurations.last()
-                    gnd_nodes = eq.get_reference_nodes()
+                    gnd_nodes = set(eq.get_reference_nodes())
                 except KeyError:
                     gnd_nodes = set()
 
+                gnd_nodes |= preferred_gnd_nodes
                 switch_configured_graph = create_switch_configured_graph(switch_config)
 
                 equation = MNAEquationStack(
@@ -275,13 +283,11 @@ class Circuit:
                         if isinstance(branch, CurrentBranch):
                             v = eq.get_voltage(result, branch)
                             i = branch.get_current(coupled_v_i, t1, t2)
-                            branch.update(v, coupled_v_i, t1, t2)
                             sim.branch_voltages[branch].append(v)
                             sim.branch_currents[branch].append(i)
                         elif isinstance(branch, VoltageBranch):
                             i = eq.get_current(result, branch)
                             v = branch.get_voltage(coupled_v_i, t1, t2)
-                            branch.update(i, coupled_v_i, t1, t2)
                             sim.branch_voltages[branch].append(v)
                             sim.branch_currents[branch].append(i)
                         elif isinstance(branch, SwitchBranch):
@@ -294,6 +300,8 @@ class Circuit:
                         else:
                             raise AssertionError(f'Unknown branch type encountered: f{type(branch)}')
 
+                    component.update(coupled_v_i, t1, t2)
+
                     # Save state results now that components are updated.
                     sim.component_states[component].append(component.state)
 
@@ -434,7 +442,12 @@ class Circuit:
         simulation.finish()
         return simulation
 
-    def simulate_efm(self, t0: float, T: float, interval_steps: int, skips: List[int]) -> TransientEFMSimulation:
+    def simulate_efm(self,
+                     t0: float,
+                     T: float,
+                     interval_steps: int,
+                     skips: List[int],
+                     preferred_ground_nodes: Set = frozenset()) -> TransientEFMSimulation:
         """
         Simulates the circuit using the envelope-following-method (EFM).
 
@@ -469,6 +482,8 @@ class Circuit:
             How many steps to simulate for a single interval.
         :param skips:
             Consecutive skips to perform encoded in a list.
+        :param preferred_ground_nodes:
+            Notes to prefer as ground (GND).
         :return:
             A `TransientEFMSimulation` object containing the result of the simulation.
             Note that computation happens *asynchronously*!.
@@ -481,14 +496,14 @@ class Circuit:
 
         simulation = TransientEFMSimulation(skips, self._component_branches, self._graph.nodes)
 
-        def simulate_efm_async(simulation, t0, T, interval_steps, skips):
+        def simulate_efm_async(simulation, t0, T, interval_steps, skips, preferred_ground_nodes):
             try:
-                self._simulate_efm(simulation, t0, T, interval_steps, skips)
+                self._simulate_efm(simulation, t0, T, interval_steps, skips, preferred_ground_nodes)
             except Exception as ex:
                 simulation.abort(ex)
 
         Thread(target=simulate_efm_async,
-               args=(simulation, t0, T, interval_steps, skips)).start()
+               args=(simulation, t0, T, interval_steps, skips, preferred_ground_nodes)).start()
 
         return simulation
 
@@ -497,7 +512,8 @@ class Circuit:
                       t0: float,
                       T: float,
                       interval_steps: int,
-                      skips: List[int]):
+                      skips: List[int],
+                      preferred_ground_nodes: Set = frozenset()):
 
         # shorthand prefixes for variables: li -> left interval, ri -> right interval
 
@@ -511,7 +527,7 @@ class Circuit:
 
             li_state1, state_compactification = compact([component.state for component in self.components])
             li_state1 = np.array(li_state1)
-            subsim = self.simulate(li_ts1, li_ts2, interval_steps)
+            subsim = self.simulate(li_ts1, li_ts2, interval_steps, preferred_ground_nodes)
             subsim.wait()
             li_state2, _ = compact([component.state for component in self.components])
             li_state2 = np.array(li_state2)
@@ -528,7 +544,7 @@ class Circuit:
                     component.state = state
 
                 ri_state1 = np.array(ri_state1)
-                self.simulate(ri_ts1, ri_ts2, interval_steps).wait()
+                self.simulate(ri_ts1, ri_ts2, interval_steps, preferred_ground_nodes).wait()
                 ri_state2, _ = compact([component.state for component in self.components])
                 ri_state2 = np.array(ri_state2)
                 ri_state_delta = ri_state2 - ri_state1
@@ -552,7 +568,7 @@ class Circuit:
 
         # With steps > 0 being enforced above, referencing i won't cause any problems. The loop runs at least once.
         li_ts2 = li_ts1 + T
-        subsim = self.simulate(li_ts1, li_ts2, interval_steps)
+        subsim = self.simulate(li_ts1, li_ts2, interval_steps, preferred_ground_nodes)
         subsim.wait()
 
         with simulation as sim:
@@ -561,7 +577,7 @@ class Circuit:
         simulation.finish()
         return simulation
 
-    def steadystate(self, T, steps, t0=0) -> TransientSteadyStateSimulation:
+    def steadystate(self, T, steps, t0=0, preferred_ground_nodes: Set = frozenset()) -> TransientSteadyStateSimulation:
         """
         Finds the periodic steady-state solution of the circuit.
 
@@ -586,24 +602,31 @@ class Circuit:
             For sinusoidal sources, can be approximately set to `10 * T / min(Ts)`.
         :param t0:
             Initial time to start simulation from.
+        :param preferred_ground_nodes:
+            Notes to prefer as ground (GND).
         :return:
             A simulation object.
             Note that computation happens *asynchronously*!
         """
         simulation = TransientSteadyStateSimulation(t0, t0 + T, self._component_branches, self._graph.nodes)
 
-        def steadystate_async(simulation, T, steps, t0):
+        def steadystate_async(simulation, T, steps, t0, preferred_ground_nodes):
             try:
-                self._steadystate(simulation, T, steps, t0)
+                self._steadystate(simulation, T, steps, t0, preferred_ground_nodes)
             except Exception as ex:
                 simulation.abort(ex)
 
         Thread(target=steadystate_async,
-               args=(simulation, T, steps, t0)).start()
+               args=(simulation, T, steps, t0, preferred_ground_nodes)).start()
 
         return simulation
 
-    def _steadystate(self, simulation: TransientSteadyStateSimulation, T: float, steps: int, t0=0):
+    def _steadystate(self,
+                     simulation: TransientSteadyStateSimulation,
+                     T: float,
+                     steps: int,
+                     t0=0,
+                     preferred_ground_nodes=frozenset()):
         state0, state_compactification = compact([component.state for component in self.components])
 
         ts1 = t0
@@ -615,7 +638,7 @@ class Circuit:
             for component, state in zip(self.components, states):
                 component.state = state
 
-            self.simulate(ts1, ts2, steps).wait()
+            self.simulate(ts1, ts2, steps, preferred_ground_nodes).wait()
 
             new_state, _ = compact([component.state for component in self.components])
 
@@ -627,7 +650,7 @@ class Circuit:
         for component, state in zip(self.components, states):
             component.state = state
 
-        subsim = self.simulate(ts1, ts2, steps)
+        subsim = self.simulate(ts1, ts2, steps, preferred_ground_nodes)
         subsim.wait()
 
         with simulation as sim:
@@ -641,7 +664,8 @@ class Circuit:
                               *Ts: float,
                               fast_steps: int = 10,
                               subdivisions: Union[int, Collection] = 8,
-                              periodicity_tolerance: float = 2**-26) -> TransientSteadyStateEFMSimulation:
+                              periodicity_tolerance: float = 2**-26,
+                              preferred_ground_nodes: Set = frozenset()) -> TransientSteadyStateEFMSimulation:
         """
         Finds the periodic steady-state solution of the circuit using the envelope-following-method (EFM) for
         multi-rate systems.
@@ -691,6 +715,8 @@ class Circuit:
 
             Especially reduce this value if you require lower period times than this tolerance, otherwise
             they will be effectively rounded to 0.
+        :param preferred_ground_nodes:
+            Notes to prefer as ground (GND).
         :return:
             A simulation object containing the steady-state solution.
             Note that computation happens *asynchronously*!
@@ -715,14 +741,14 @@ class Circuit:
 
         simulation = TransientSteadyStateEFMSimulation(skips, self._component_branches, self._graph.nodes)
 
-        def multirate_steadystate_async(simulation, t0, T_fast, T_fast_steps, skips):
+        def multirate_steadystate_async(simulation, t0, T_fast, T_fast_steps, skips, preferred_ground_nodes):
             try:
-                self._multirate_steadystate(simulation, t0, T_fast, T_fast_steps, skips)
+                self._multirate_steadystate(simulation, t0, T_fast, T_fast_steps, skips, preferred_ground_nodes)
             except Exception as ex:
                 simulation.abort(ex)
 
         Thread(target=multirate_steadystate_async,
-               args=(simulation, t0, T_fast, fast_steps, skips)).start()
+               args=(simulation, t0, T_fast, fast_steps, skips, preferred_ground_nodes)).start()
 
         return simulation
 
@@ -731,7 +757,8 @@ class Circuit:
                                t0: float,
                                T_fast: float,
                                T_fast_steps: int,
-                               skips: List[int]):
+                               skips: List[int],
+                               preferred_ground_nodes: Set = frozenset()):
 
         state0, state_compactification = compact([component.state for component in self.components])
 
@@ -740,7 +767,7 @@ class Circuit:
             for component, state in zip(self.components, states):
                 component.state = state
 
-            self.simulate_efm(t0, T_fast, T_fast_steps, skips).wait()
+            self.simulate_efm(t0, T_fast, T_fast_steps, skips, preferred_ground_nodes).wait()
 
             final_interval_state, _ = compact([component.state for component in self.components])
             final_interval_state = np.array(final_interval_state)
@@ -752,7 +779,7 @@ class Circuit:
         for component, state in zip(self.components, states):
             component.state = state
 
-        subsim = self.simulate_efm(t0, T_fast, T_fast_steps, skips)
+        subsim = self.simulate_efm(t0, T_fast, T_fast_steps, skips, preferred_ground_nodes)
         subsim.wait()
 
         with simulation as sim:
