@@ -288,6 +288,8 @@ class TransientSimulation:
             * v: voltage plot
             * i: current plot
             * p: power plot
+            * s: component states
+            * c: *c*ontrolled switch states
         :param throw:
             Whether exceptions from the computation thread are thrown in the calling thread.
             Set it to `False` if you also want to print partial results.
@@ -295,6 +297,16 @@ class TransientSimulation:
         if not features:
             raise ValueError('no features specified')
 
+        component_features = {}
+        branch_features = {}
+        for i, feature in enumerate(features, start=1):
+            if feature == 'v' or feature == 'i' or feature == 'p' or feature == 'c':
+                branch_features[i] = feature
+            elif feature == 's':
+                component_features[i] = feature
+            else:
+                raise ValueError(f'invalid feature: {feature}')
+
         self.wait(throw=throw)
 
         # Determine necessary components and respective branches to plot.
@@ -327,17 +339,39 @@ class TransientSimulation:
 
         for component, branches in plotset.items():
             color = next(colorcycle)
+
+            for i, feature in component_features.items():
+                # Currently there is only the "state"-feature, no need for an if-else.
+                for k, states in enumerate(zip(*self.get_states(component))):
+                    fig.append_trace(
+                        Scatter(
+                            x=self._ts,
+                            y=states,
+                            name=f'state({component})[{k}]',
+                            mode='lines',
+                            line={'color': color},
+                            showlegend=True,
+                        ),
+                        row=i,
+                        col=1,
+                    )
+
             for branch in branches:
                 showlegend = True
-                for i, feature in enumerate(features, start=1):
+                for i, feature in branch_features.items():
                     if feature == 'v':
                         get_solutions = self.get_voltages
                     elif feature == 'i':
                         get_solutions = self.get_currents
                     elif feature == 'p':
                         get_solutions = self.get_power
+                    elif feature == 'c':
+                        if not isinstance(branch, SwitchBranch):
+                            continue
+
+                        get_solutions = lambda branch: [1 if s else 0 for s in self.get_switch_states(branch)]
                     else:
-                        raise ValueError(f'invalid feature: {feature}')
+                        raise AssertionError
 
                     fig.append_trace(
                         Scatter(
@@ -356,15 +390,25 @@ class TransientSimulation:
                     showlegend = False
 
         # Update xaxis properties
-        for i, feature in enumerate(features, start=1):
-            if feature == 'v':
-                title_text = 'voltage V [V]'
-            elif feature == 'i':
-                title_text = 'current I [A]'
-            else:  # --> feature == 'p'
-                title_text = 'power P [W]'
+        axis_labels = {
+            'v': 'voltage V [V]',
+            'i': 'current I [A]',
+            'p': 'power P [W]',
+            's': 'state',
+            'c': 'switch state',
+        }
 
-            fig.update_yaxes(row=i, col=1, title_text=title_text)
+        for i, feature in enumerate(features, start=1):
+            fig.update_yaxes(row=i, col=1, title_text=axis_labels[feature])
+
+            if feature == 'c':
+                fig.update_yaxes(
+                    row=i,
+                    col=1,
+                    tickmode='array',
+                    tickvals=[0, 1],
+                    ticktext=['off', 'on'],
+                )
 
         fig.update_xaxes(row=len(features), col=1, title_text="time t [s]")
         fig.update_layout(title="Transient Simulation Results")
