@@ -1,5 +1,7 @@
 from collections.abc import MutableMapping
 
+from ordered_set import OrderedSet
+
 
 class OneToManyInvertibleMapping(MutableMapping):
     class _ReverseDict(MutableMapping):
@@ -37,7 +39,7 @@ class OneToManyInvertibleMapping(MutableMapping):
             if value in self._obverse._obverse:
                 obverse_set = self._obverse[value]
             else:
-                obverse_set = set()
+                obverse_set = OrderedSet()
                 self._obverse._obverse[value] = obverse_set
 
             obverse_set.add(key)
@@ -90,13 +92,13 @@ class OneToManyInvertibleMapping(MutableMapping):
         return self._obverse.items()
 
     def __getitem__(self, key):
-        return frozenset(self._obverse[key])
+        return self._obverse[key].copy()
 
     def __setitem__(self, key, value):
         if key in self._obverse:
             obverse_set = self._obverse[key]
         else:
-            obverse_set = set()
+            obverse_set = OrderedSet()
             self._obverse[key] = obverse_set
 
         obverse_set.add(value)
