@@ -15,20 +15,21 @@ class OperationalAmplifier(Component):
     Describes an (almost) ideal operational amplifier ("op-amp").
 
     An ideal op-amp has following idealizing characteristics:
-    - Infinite open-loop gain (this is the only aspect which does not hold for this op-amp implementation, it's finite)
-    - Infinite input impedance, and so zero input current
-    - Zero input offset voltage
-    - Infinite output voltage range
-    - Infinite bandwidth with zero phase shift and infinite slew rate
-    - Zero output impedance
-    - Zero noise
+    * Infinite open-loop gain (this is the only aspect which does not hold for this op-amp implementation, it's finite)
+    * Infinite input impedance, and so zero input current
+    * Zero input offset voltage
+    * Infinite output voltage range
+    * Infinite bandwidth with zero phase shift and infinite slew rate
+    * Zero output impedance
+    * Zero noise
 
     See also https://en.wikipedia.org/wiki/Operational_amplifier#Ideal_op-amps
 
     This component is connected in following order:
-    - First two terminals denote the input voltages V_in_- and V_in_+. The difference between them is what is amplified.
-    - The third terminal denotes GND (ground) or any reference potential you want to use.
-    - The fourth terminal denotes the output voltage V_out (in reference to GND).
+    * First two terminals denote the input voltages :math:`V_{in-}` and :math:`V_{in+}`.
+    The difference between them is what is amplified.
+    * The third terminal denotes GND (ground) or any reference potential you want to use.
+    * The fourth terminal denotes the output voltage V_out (in reference to GND).
 
     g:
         Open loop gain. For real op-amps this value lies between 20000 and 200000.
